@@ -28,12 +28,16 @@ class FirefoxBinary(object):
 
     def __init__(self, firefox_path=None):
         self._start_cmd = firefox_path
+        self.command_line = None
         if self._start_cmd is None:
             self._start_cmd = self._get_firefox_start_cmd()
         # Rather than modifying the environment of the calling Python process
         # copy it and modify as needed.
         self._firefox_env = os.environ.copy()
 
+    def add_command_line_options(self, *args):
+        self.command_line = args
+
     def launch_browser(self, profile):
         """Launches the browser for the given profile name.
         It is assumed the profile already exists.
@@ -57,14 +61,19 @@ class FirefoxBinary(object):
         self._firefox_env["MOZ_CRASHREPORTER_DISABLE"] = "1"
         self._firefox_env["MOZ_NO_REMOTE"] = "1"
         self._firefox_env["NO_EM_RESTART"] = "1"
-        
+
         if platform.system().lower() == 'linux':
             self._modify_link_library_path()
-        
-        Popen([self._start_cmd, "-silent"], stdout=PIPE, stderr=STDOUT,
-              env=self._firefox_env).wait()
+        command = [self._start_cmd, "-silent"]
+        if self.command_line is not None:
+            for cli in self.command_line:
+                command.append(cli)
+
+        Popen(command, stdout=PIPE, stderr=STDOUT,
+              env=self._firefox_env).communicate()
+        command[1] = '-foreground'
         self.process = Popen(
-            [self._start_cmd, "-foreground"], stdout=PIPE, stderr=STDOUT,
+            command, stdout=PIPE, stderr=STDOUT,
             env=self._firefox_env)
 
     def _get_firefox_output(self):
@@ -101,7 +110,7 @@ class FirefoxBinary(object):
                 key = OpenKey(HKEY_LOCAL_MACHINE, path)
                 command = QueryValue(key, "")
                 break
-            except WindowsError:
+            except OSError:
                 pass
         else:
             return ""
@@ -116,12 +125,17 @@ class FirefoxBinary(object):
         elif platform.system() == "Windows":
             start_cmd = (self._find_exe_in_registry() or 
                 self._default_windows_location())
+        elif platform.system() == 'Java' and os._name == 'nt':
+            start_cmd = self._default_windows_location()
         else:
-            # Maybe iceweasel (Debian) is another candidate...
-            for ffname in ["firefox2", "firefox", "firefox-3.0", "firefox-4.0"]:
+            for ffname in ["firefox", "iceweasel"]:
                 start_cmd = self.which(ffname)
                 if start_cmd is not None:
                     break
+            else:
+                # couldn't find firefox on the system path
+                raise RuntimeError("Could not find firefox in your system PATH." + 
+                    " Please specify the firefox binary location or install firefox")
         return start_cmd
 
     def _default_windows_location(self):
