@@ -24,14 +24,15 @@ class Service(object):
     Object that manages the starting and stopping of PhantomJS / Ghostdriver
     """
 
-    def __init__(self, executable_path, port=0, service_args=None):
+    def __init__(self, executable_path, port=0, service_args=None, log_path=None):
         """
         Creates a new instance of the Service
-        
+
         :Args:
          - executable_path : Path to PhantomJS binary
-         - port : Port the service is running on 
+         - port : Port the service is running on
          - service_args : A List of other command line options to pass to PhantomJS
+         - log_path: Path for PhantomJS service to log to
         """
 
         self.port = port
@@ -43,12 +44,14 @@ class Service(object):
             self.service_args = []
         self.service_args.insert(0, self.path)
         self.service_args.append("--webdriver=%d" % self.port)
-        self._log = open("ghostdriver.log", 'w')
+        if not log_path:
+            log_path = "ghostdriver.log"
+        self._log = open(log_path, 'w')
 
     def start(self):
         """
-        Starts PhantomJS with GhostDriver. 
-        
+        Starts PhantomJS with GhostDriver.
+
         :Exceptions:
          - WebDriverException : Raised either when it can't start the service
            or when it can't connect to the service
@@ -64,7 +67,7 @@ class Service(object):
             time.sleep(1)
             if count == 30:
                  raise WebDriverException("Can not connect to GhostDriver")
-                
+
     @property
     def service_url(self):
         """
@@ -73,7 +76,7 @@ class Service(object):
         return "http://localhost:%d/wd/hub" % self.port
 
     def stop(self):
-        """ 
+        """
         Cleans up the process
         """
         if self._log:
@@ -88,6 +91,6 @@ class Service(object):
             if self.process:
                 self.process.kill()
                 self.process.wait()
-        except WindowsError:
+        except OSError:
             # kill may not be available under windows environment
             pass
