@@ -1,5 +1,4 @@
-# Copyright 2008-2011 WebDriver committers
-# Copyright 2008-2011 Google Inc.
+# Copyright 2008-2013 Software freedom conservancy
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -21,8 +20,10 @@ from webelement import WebElement
 from remote_connection import RemoteConnection
 from errorhandler import ErrorHandler
 from selenium.common.exceptions import WebDriverException
+from selenium.common.exceptions import InvalidSelectorException
 from selenium.webdriver.common.by import By
 from selenium.webdriver.common.alert import Alert
+from selenium.webdriver.common.html5.application_cache import ApplicationCache
 
 
 class WebDriver(object):
@@ -36,10 +37,11 @@ class WebDriver(object):
      - error_handler - errorhandler.ErrorHandler object used to verify that the server did not return an error.
      - session_id - The session ID to send with every command.
      - capabilities - A dictionary of capabilities of the underlying browser for this instance's session.
+     - proxy - A selenium.webdriver.common.proxy.Proxy object, to specify a proxy for the browser to use.
     """
 
     def __init__(self, command_executor='http://127.0.0.1:4444/wd/hub',
-        desired_capabilities=None, browser_profile=None):
+        desired_capabilities=None, browser_profile=None, proxy=None):
         """
         Create a new driver that will issue commands using the wire protocol.
 
@@ -52,9 +54,12 @@ class WebDriver(object):
             raise WebDriverException("Desired Capabilities can't be None")
         if not isinstance(desired_capabilities, dict):
             raise WebDriverException("Desired Capabilities must be a dictionary")
+        if proxy is not None:
+            proxy.add_to_capabilities(desired_capabilities)
         self.command_executor = command_executor
         if type(self.command_executor) is str or type(self.command_executor) is unicode:
             self.command_executor = RemoteConnection(command_executor)
+        self._is_remote = True
         self.session_id = None
         self.capabilities = {}
         self.error_handler = ErrorHandler()
@@ -634,7 +639,7 @@ class WebDriver(object):
            execute_async_script call before throwing an error.
 
         :Args:
-         - time_to_wait: The amount of time to wait
+         - time_to_wait: The amount of time to wait (in seconds)
 
         :Usage:
             driver.set_script_timeout(30)
@@ -644,7 +649,7 @@ class WebDriver(object):
 
     def set_page_load_timeout(self, time_to_wait):
         """
-        Set the amount of time to wait for a page load to complete 
+        Set the amount of time to wait for a page load to complete
            before throwing an error.
 
         :Args:
@@ -663,6 +668,9 @@ class WebDriver(object):
         :Usage:
             Use the corresponding find_element_by_* instead of this.
         """
+        if isinstance(by, tuple) or isinstance(value, int) or value==None:
+            raise InvalidSelectorException("Invalid locator values passed in")
+
         return self.execute(Command.FIND_ELEMENT,
                              {'using': by, 'value': value})['value']
 
@@ -673,6 +681,9 @@ class WebDriver(object):
         :Usage:
             Use the corresponding find_elements_by_* instead of this.
         """
+        if isinstance(by, tuple) or isinstance(value, int) or value==None:
+            raise InvalidSelectorException("Invalid locator values passed in")
+
         return self.execute(Command.FIND_ELEMENTS,
                              {'using': by, 'value': value})['value']
     @property
@@ -786,3 +797,28 @@ class WebDriver(object):
             self.execute(Command.SET_SCREEN_ORIENTATION, {'orientation': value})['value']
         else:
             raise WebDriverException("You can only set the orientation to 'LANDSCAPE' and 'PORTRAIT'")
+
+    def is_online(self):
+        """ Returns a boolean if the browser is online or offline"""
+        return self.execute(Command.IS_BROWSER_ONLINE)['value']
+
+    @property
+    def application_cache(self):
+        """ Returns a ApplicationCache Object to interact with the browser app cache"""
+        return ApplicationCache(self)
+
+    def save_screenshot(self, filename):
+        """
+        Gets the screenshot of the current window. Returns False if there is
+        any IOError, else returns True. Use full paths in your filename.
+        """
+        png = self.execute(Command.SCREENSHOT)['value']
+        try:
+            f = open(filename, 'wb')
+            f.write(base64.decodestring(png))
+            f.close()
+        except IOError:
+            return False
+        finally:
+            del png
+        return True
